==> cosmos-rm-incubation-sdk-COSMOS-1.0.0-200806252052.zip: org/eclipse/cosmos/rm/internal/validation/common/ISMLConstants.java <==
/**********************************************************************
 * Copyright (c) 2007, 2008 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 * SAS - Fix for defect 236866
 **********************************************************************/
package org.eclipse.cosmos.rm.internal.validation.common;

/**
 * Defines constants that are specific to the SML/SML-IF documents
 * 
 * @author Ali Mehregani
 */
public class ISMLConstants
{

	public static final String XML_PREAMBLE = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";

	/**
	 * Elements
	 */
	public static final String DOCUMENT_ELEMENT = "document";
	public static final String ALIAS_ELEMENT = "alias";
	public static final String ALIASES_ELEMENT = "aliases";	
	public static final String URI_ELEMENT = "uri";	
	public static final String DOCUMENTURI_ELEMENT = "documentURI";
	public static final String DEFINITIONS_ELEMENT = "definitions";
	public static final String INSTANCES_ELEMENT = "instances";
    public static final String COMPLEXTYPE_ELEMENT = "complexType";
    public static final String ELEMENT_ELEMENT = "element";
    public static final String EXTENSION_ELEMENT = "extension";    
    public static final String DATA_ELEMENT = "data";
    public static final String SCHEMA_ELEMENT = "schema";
    public static final String KEY_ELEMENT = "key";
    public static final String KEY_REF_ELEMENT = "keyref";
    public static final String UNIQUE_ELEMENT = "unique";
    public static final String SML_SELECTOR = "selector";
    public static final String SML_FIELD = "field";
    public static final String IDENTITY_ELEMENT = "identity";
    public static final String NAME_ELEMENT = "name";
    public static final String DESCRIPTION_ELEMENT = "description";
    public static final String RULE_ELEMENT = "rule";
    public static final String ANNOTATION_ELEMENT = "annotation";
    public static final String APP_INFO_ELEMENT = "appinfo";    
    public static final String SELECTOR_ELEMENT = "selector";
    public static final String FIELD_ELEMENT = "field";
    public static final String NS_ELEMENT = "ns";
    public static final String RULEBINDING_ELEMENT = "ruleBinding";
    public static final String RULEBINDINGS_ELEMENT = "ruleBindings";
	public static final String LOCATOR_ELEMENT = "locator";    
	public static final String DOC_INFO_ELEMENT = "docinfo";
	public static final String MODEL_ELEMENT = "model";
	public static final String DISPLAY_NAME_ELEMENT = "displayName";
	public static final String VERSION_ELEMENT = "version";
	public static final String DIAGNOSTIC_ELEMENT = "diagnostic";
	public static final String REPORT_ELEMENT = "report";
	public static final String ASSERT_ELEMENT = "assert";
	public static final String PATTERN_ELEMENT = "pattern";
    public static final String DOCUMENTALIAS_ELEMENT = "documentAlias";
    public static final String RULEALIAS_ELEMENT = "ruleAlias";
	public static final String IMPORT_ELEMENT = "import";
	public static final String RESTRICTION_ELEMENT = "restriction";
	public static final String SEQUENCE_ELEMENT = "sequence";
	public static final String GROUP_ELEMENT = "group";	
    public static final String SCHEMA_BINDINGS_ELEMENT = "schemaBindings";
    public static final String BASE_URI_ELEMENT = "baseURI";
    
    /**
     * Data builders interested in fragments that precede the definition/instance
     * section should use this constant
     */
    public static final byte START_PHASE=0x02;
    
    /**
     * Indicates that the entire document is being 
     * processed
     */
    public static final byte UNKNOWN_PHASE=0x03;
    /**
     * Indicates that the definition section of the document is being 
     * processed
     */
    public static final byte DEFINITIONS_PHASE=0x01;
    
    /**
     * Indicates that the instance section of the document is being 
     * processed 
     */
    public static final byte INSTANCES_PHASE=0x10;
    
    /**
     * Data builder interested to be notified while the definition or instance
     * section is being processed should use this constant.
     */
    public static final byte DEFINITIONS_INSTANCES_PHASE=0x00;
	
    
    /**
     * Indicates that the Locator section of the document is being
     * processed
     */
    public static final byte LOCATOR_PHASE=0x04;
    
    /**
     * Indicates that the documentURI section of the document is being
     * processed
     */
    public static final byte DOCUMENTURI_PHASE=0x05;
    
	/**
	 * Attributes
	 */	   
	public static final String ACYCLIC_ATTRIBUTE = "acyclic";
	public static final String BASE_ATTRIBUTE = "base";	
	public static final String NAME_ATTRIBUTE = "name";	
    public static final String TYPE_ATTRIBUTE ="type";
    public static final String SUBSTITUTIONGROUP_ATTRIBUTE = "substitutionGroup";
    public static final String TARGETELEMENT_ATTRIBUTE="targetElement";
    public static final String TARGET_NAMESPACE_ATTRIBUTE="targetNamespace";
    public static final String TARGETTYPE_ATTRIBUTE="targetType";
    public static final String XPATH_ATTRIBUTE ="xpath";    
    public static final String URI_ATTRIBUTE ="uri";    
    public static final String TARGETREQUIRED_ATTRIBUTE="targetRequired";        
    public static final String XML_NS_ATTRIBUTE = "xmlns";
    public static final String CONTEXT_ATTRIBUTE = "context";
    public static final String REFER_ATTRIBUTE = "refer";
    public static final String PREFIX_ATTRIBUTE = "prefix";
	public static final String HREF_ATTRIBUTE = "href";    
	public static final String LOCID_ATTRIBUTE = "locid";    
	public static final String EXPRESSION_ATTRIBUTE = "expression";    
	public static final String ID_ATTRIBUTE = "id";    
	public static final String SCHEMA_LOCATION_ATTRIBUTE = "schemaLocation";
	public static final String NAMESPACE_ATTRIBUTE = "namespace";
	public static final String REF_ATTRIBUTE = "ref";
	public static final String SCHEMA_COMPLETE_ATTR = "schemaComplete";
	public static final String URI_NILREF = "nilref";
           
	/**
	 * schema binding attributes
	 */
	public static final String SCHEMA_BINDING_NMS_ATTR = "namespace";
	public static final String SCHEMA_BINDING_ALIASES_ATTR = "aliases";
	/**
	 * Signifies that the sml:uri value is null
	 */
	public static final String SML_URI_VALUE_NULL="sml.uri.value.null";
	  
	 
	/**
	 * XPath Extension functions
	 */
	public static final String DEREF_FN = "deref";
	
	/**
	 * Context parameter that is used to specify the rule context
     */
	public static final String CONTEXTPARAM = "$contextParam"; 
	
	/**
	 * Delimiter to signify type key
     */
	public static final String TYPEDELIM = "$typeDelim"; 	
	
	/**
	 * Used to identify definition documents
	 */
	public static final int TYPE_DEFINITION = 0;
	
	/**
	 * Used to identify instance documents
	 */
	public static final int TYPE_INSTANCE = 1;
		
	/**
	 * Used to identify sml-if document types
	 */
	public static final int TYPE_SMLIF = 2;
	
	/**
	 * Used to identify an unknown content type 
	 */
	public static final int TYPE_UNKNOWN = 3;	
	
	/**
	 * Target namespaces
	 */
	public static final String SML_URI = "http://www.w3.org/2008/03/sml";
	public static final String SCHEMATRON_URI = "http://purl.oclc.org/dsdl/schematron";	
	public static final String SMLIF_URI = "http://www.w3.org/2008/03/sml-if";
	public static final String SCHEMA_URI = "http://www.w3.org/2001/XMLSchema";
	public static final String SCHEMA_INSTANCE_URI = "http://www.w3.org/2001/XMLSchema-instance";
	public static final String XSL_URI = "http://www.w3.org/1999/XSL/Transform";	
	public static final String SML_FN_URI = "http://www.w3.org/2008/03/sml-function";
	public static final String XLINK_URI = "http://www.w3.org/1999/xlink";
	
	/**
	 * SAX parser constants
	 */
	public static final String SAX_PARSER_PROPERTY_SCHEMA_SOURCE = "http://java.sun.com/xml/jaxp/properties/schemaSource";
	public static final String SAX_PARSER_PROPERTY_SCHEMA_LANGUAGE = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
	public static final String SAX_PARSER_PROPERTY_LEXICAL_HANDLER = "http://xml.org/sax/properties/lexical-handler";
	public static final String SAX_PARSER_FEATURE_VALIDATION = "http://xml.org/sax/features/validation";
	public static final String SAX_PARSER_FEATURE_NAMESPACE_PREFIXES = "http://xml.org/sax/features/namespace-prefixes";
	public static final String SAX_PARSER_FEATURE_NAMESPACES = "http://xml.org/sax/features/namespaces";
	
	/**
	 * DOM serializer constants
	 */
	public static final String DOM_CONFIG_XML_DECLARATION = "xml-declaration";
	public static final String DOM_CONFIG_NAMESPACE_DECLARATIONS = "namespace-declarations";

	/**
	 * Namespace constants
	 */
	public static final String SMLERR_NAMESPACE_PREFIX = "smlerr";	
	public static final String SMLIF_NAMESPACE_PREFIX = "smlif";

	/**
	 * character constants
	 */
	public static final String nl = "\n";
	public static final String tab = "\t";
	public static final String space = " ";
	
	public static final String COLON = ":";
	public static final String OPEN_ANGLE_BRACKET = "<";
	public static final String FORWARD_SLASH = "/";
	public static final String CLOSE_ANGLE_BRACKET = ">";
	public static final String COMMA = ",";
	public static final String EQUAL_SIGN = "=";
	public static final String SINGLE_SPACE = " ";
	public static final String DOUBLE_QUOTE = "\"";
	public static final String PERIOD = ".";
	public static final String EMPTY_STRING = "";
	public static final String UTF_8 = "UTF-8";	
}

==> cosmos-rm-incubation-sdk-COSMOS-1.0.0-200808061030.zip: org/eclipse/cosmos/rm/internal/validation/common/ISMLConstants.java <==
/**********************************************************************
 * Copyright (c) 2007, 2008 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 * SAS - Fix for defect 236866
 **********************************************************************/
package org.eclipse.cosmos.rm.internal.validation.common;

/**
 * Defines constants that are specific to the SML/SML-IF documents
 * 
 * @author Ali Mehregani
 */
public class ISMLConstants
{

	public static final String XML_PREAMBLE = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";

	/**
	 * Elements
	 */
	public static final String DOCUMENT_ELEMENT = "document";
	public static final String ALIAS_ELEMENT = "alias";
	public static final String ALIASES_ELEMENT = "aliases";	
	public static final String URI_ELEMENT = "uri";	
	public static final String DOCUMENTURI_ELEMENT = "documentURI";
	public static final String DEFINITIONS_ELEMENT = "definitions";
	public static final String INSTANCES_ELEMENT = "instances";
    public static final String COMPLEXTYPE_ELEMENT = "complexType";
    public static final String ELEMENT_ELEMENT = "element";
    public static final String EXTENSION_ELEMENT = "extension";    
    public static final String DATA_ELEMENT = "data";
    public static final String SCHEMA_ELEMENT = "schema";
    public static final String KEY_ELEMENT = "key";
    public static final String KEY_REF_ELEMENT = "keyref";
    public static final String UNIQUE_ELEMENT = "unique";
    public static final String SML_SELECTOR = "selector";
    public static final String SML_FIELD = "field";
    public static final String IDENTITY_ELEMENT = "identity";
    public static final String NAME_ELEMENT = "name";
    public static final String DESCRIPTION_ELEMENT = "description";
    public static final String RULE_ELEMENT = "rule";
    public static final String ANNOTATION_ELEMENT = "annotation";
    public static final String APP_INFO_ELEMENT = "appinfo";    
    public static final String SELECTOR_ELEMENT = "selector";
    public static final String FIELD_ELEMENT = "field";
    public static final String NS_ELEMENT = "ns";
    public static final String RULEBINDING_ELEMENT = "ruleBinding";
    public static final String RULEBINDINGS_ELEMENT = "ruleBindings";
	public static final String LOCATOR_ELEMENT = "locator";    
	public static final String DOC_INFO_ELEMENT = "docinfo";
	public static final String MODEL_ELEMENT = "model";
	public static final String DISPLAY_NAME_ELEMENT = "displayName";
	public static final String VERSION_ELEMENT = "version";
	public static final String DIAGNOSTIC_ELEMENT = "diagnostic";
	public static final String REPORT_ELEMENT = "report";
	public static final String ASSERT_ELEMENT = "assert";
	public static final String PATTERN_ELEMENT = "pattern";
    public static final String DOCUMENTALIAS_ELEMENT = "documentAlias";
    public static final String RULEALIAS_ELEMENT = "ruleAlias";
	public static final String IMPORT_ELEMENT = "import";
	public static final String RESTRICTION_ELEMENT = "restriction";
	public static final String SEQUENCE_ELEMENT = "sequence";
	public static final String GROUP_ELEMENT = "group";	
    public static final String SCHEMA_BINDING_ELEMENT = "schemaBinding";
    public static final String BASE_URI_ELEMENT = "baseURI";
    public static final String ANY_TYPE_ELEMENT = "anyType";	    
	public static final String DEFAULT_SCHEMA_ELEMENT = "defaultSchema";
	public static final String NAMESPACE_BINDING_ELEMENT = "namespaceBinding";
	public static final String DOCUMENT_ALIAS_ELEMENT = "documentAlias";	
	public static final String SCHEMA_BINDINGS_ELEMENT = "schemaBindings";
    
	/**
	 * Attributes
	 */	   
	public static final String ACYCLIC_ATTRIBUTE = "acyclic";
	public static final String BASE_ATTRIBUTE = "base";	
	public static final String NAME_ATTRIBUTE = "name";	
    public static final String TYPE_ATTRIBUTE ="type";
    public static final String SUBSTITUTIONGROUP_ATTRIBUTE = "substitutionGroup";
    public static final String TARGETELEMENT_ATTRIBUTE="targetElement";
    public static final String TARGET_NAMESPACE_ATTRIBUTE="targetNamespace";
    public static final String TARGETTYPE_ATTRIBUTE="targetType";
    public static final String XPATH_ATTRIBUTE ="xpath";    
    public static final String URI_ATTRIBUTE ="uri";    
    public static final String TARGETREQUIRED_ATTRIBUTE="targetRequired";        
    public static final String XML_NS_ATTRIBUTE = "xmlns";
    public static final String CONTEXT_ATTRIBUTE = "context";
    public static final String REFER_ATTRIBUTE = "refer";
    public static final String PREFIX_ATTRIBUTE = "prefix";
	public static final String HREF_ATTRIBUTE = "href";    
	public static final String LOCID_ATTRIBUTE = "locid";    
	public static final String EXPRESSION_ATTRIBUTE = "expression";    
	public static final String ID_ATTRIBUTE = "id";    
	public static final String SCHEMA_LOCATION_ATTRIBUTE = "schemaLocation";
	public static final String NAMESPACE_ATTRIBUTE = "namespace";
	public static final String REF_ATTRIBUTE = "ref";
	public static final String SCHEMA_COMPLETE_ATTR = "schemaComplete";
	public static final String URI_NILREF = "nilref";
	public static final String ALIASES_ATTRIBUTE = "aliases";
	
	/**
	 * schema binding attributes
	 */
	public static final String SCHEMA_BINDING_NMS_ATTR = "namespace";
	public static final String SCHEMA_BINDING_ALIASES_ATTR = "aliases";
	/**
	 * Signifies that the sml:uri value is null
	 */
	public static final String SML_URI_VALUE_NULL="sml.uri.value.null";
	  
	 
	/**
	 * XPath Extension functions
	 */
	public static final String DEREF_FN = "deref";
	
	/**
	 * Context parameter that is used to specify the rule context
     */
	public static final String CONTEXTPARAM = "$contextParam"; 
	
	/**
	 * Delimiter to signify type key
     */
	public static final String TYPEDELIM = "$typeDelim"; 	
	
	/**
	 * Used to identify definition documents
	 */
	public static final int TYPE_DEFINITION = 0;
	
	/**
	 * Used to identify instance documents
	 */
	public static final int TYPE_INSTANCE = 1;
		
	/**
	 * Used to identify sml-if document types
	 */
	public static final int TYPE_SMLIF = 2;
	
	/**
	 * Used to identify an unknown content type 
	 */
	public static final int TYPE_UNKNOWN = 3;	
	
	/**
	 * Target namespaces
	 */
	public static final String SML_URI = "http://www.w3.org/2008/03/sml";
	public static final String SCHEMATRON_URI = "http://purl.oclc.org/dsdl/schematron";	
	public static final String SMLIF_URI = "http://www.w3.org/2008/03/sml-if";
	public static final String SCHEMA_URI = "http://www.w3.org/2001/XMLSchema";
	public static final String SCHEMA_INSTANCE_URI = "http://www.w3.org/2001/XMLSchema-instance";
	public static final String XSL_URI = "http://www.w3.org/1999/XSL/Transform";	
	public static final String SML_FN_URI = "http://www.w3.org/2008/03/sml-function";
	public static final String XLINK_URI = "http://www.w3.org/1999/xlink";
	
	/**
	 * SAX parser constants
	 */
	public static final String SAX_PARSER_PROPERTY_SCHEMA_SOURCE = "http://java.sun.com/xml/jaxp/properties/schemaSource";
	public static final String SAX_PARSER_PROPERTY_SCHEMA_LANGUAGE = "http://java.sun.com/xml/jaxp/properties/schemaLanguage";
	public static final String SAX_PARSER_PROPERTY_LEXICAL_HANDLER = "http://xml.org/sax/properties/lexical-handler";
	public static final String SAX_PARSER_FEATURE_VALIDATION = "http://xml.org/sax/features/validation";
	public static final String SAX_PARSER_FEATURE_NAMESPACE_PREFIXES = "http://xml.org/sax/features/namespace-prefixes";
	public static final String SAX_PARSER_FEATURE_NAMESPACES = "http://xml.org/sax/features/namespaces";
	public static final String SAX_PARSER_FEATURE_ANNOTATIONS = "http://apache.org/xml/features/generate-synthetic-annotations";
	
	/**
	 * DOM properties constants
	 */
	public static final String DOM_PARSER_PROPERTY_CLASS_NAME = "http://apache.org/xml/properties/dom/document-class-name";
	public static final String DOM_PARSER_VALUE_CLASS_NAME = "org.apache.xerces.dom.PSVIDocumentImpl";
	
	/**
	 * DOM serializer constants
	 */
	public static final String DOM_CONFIG_XML_DECLARATION = "xml-declaration";
	public static final String DOM_CONFIG_NAMESPACE_DECLARATIONS = "namespace-declarations";

	/**
	 * Namespace constants
	 */
	public static final String SMLERR_NAMESPACE_PREFIX = "smlerr";	
	public static final String SMLIF_NAMESPACE_PREFIX = "smlif";

	/**
	 * character constants
	 */
	public static final String nl = "\n";
	public static final String tab = "\t";
	public static final String space = " ";
	
	public static final String COLON = ":";
	public static final String OPEN_ANGLE_BRACKET = "<";
	public static final String FORWARD_SLASH = "/";
	public static final String CLOSE_ANGLE_BRACKET = ">";
	public static final String COMMA = ",";
	public static final String EQUAL_SIGN = "=";
	public static final String SINGLE_SPACE = " ";
	public static final String DOUBLE_QUOTE = "\"";
	public static final String PERIOD = ".";
	public static final String EMPTY_STRING = "";
	public static final String UTF_8 = "UTF-8";	
}
